==> igniteui-react-charts-18.1.0.tgz: package/esm5/lib/UltimateOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { UltimateOscillatorIndicatorCalculationStrategy } from "./UltimateOscillatorIndicatorCalculationStrategy";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var UltimateOscillatorIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(UltimateOscillatorIndicator, _super);
    function UltimateOscillatorIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    UltimateOscillatorIndicator.prototype.get_ul = function () {
        return new UltimateOscillatorIndicatorCalculationStrategy();
    };
    Object.defineProperty(UltimateOscillatorIndicator.prototype, "ul", {
        get: function () {
            return this.get_ul();
        },
        enumerable: false,
        configurable: true
    });
    UltimateOscillatorIndicator.prototype.get_uy = function () {
        return UltimateOscillatorIndicator.$;
    };
    Object.defineProperty(UltimateOscillatorIndicator.prototype, "uy", {
        get: function () {
            return this.get_uy();
        },
        enumerable: false,
        configurable: true
    });
    UltimateOscillatorIndicator.$t = markType(UltimateOscillatorIndicator, 'UltimateOscillatorIndicator', StrategyBasedIndicator.$);
    return UltimateOscillatorIndicator;
}(StrategyBasedIndicator));
export { UltimateOscillatorIndicator };

==> igniteui-react-charts-18.5.1.tgz: package/esm5/lib/UltimateOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { UltimateOscillatorIndicatorCalculationStrategy } from "./UltimateOscillatorIndicatorCalculationStrategy";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var UltimateOscillatorIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(UltimateOscillatorIndicator, _super);
    function UltimateOscillatorIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    UltimateOscillatorIndicator.prototype.bg = function () {
        return new UltimateOscillatorIndicator();
    };
    UltimateOscillatorIndicator.prototype.get_yz = function () {
        return new UltimateOscillatorIndicatorCalculationStrategy();
    };
    Object.defineProperty(UltimateOscillatorIndicator.prototype, "yz", {
        get: function () {
            return this.get_yz();
        },
        enumerable: false,
        configurable: true
    });
    UltimateOscillatorIndicator.prototype.get_zc = function () {
        return UltimateOscillatorIndicator.$;
    };
    Object.defineProperty(UltimateOscillatorIndicator.prototype, "zc", {
        get: function () {
            return this.get_zc();
        },
        enumerable: false,
        configurable: true
    });
    UltimateOscillatorIndicator.$t = markType(UltimateOscillatorIndicator, 'UltimateOscillatorIndicator', StrategyBasedIndicator.$);
    return UltimateOscillatorIndicator;
}(StrategyBasedIndicator));
export { UltimateOscillatorIndicator };
